==> xlniuxdata-vipgame-1.0.65-20161111.091755-30-sources.jar: com/xunlei/niux/data/vipgame/vo/DropEgg.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

@Table(tableName = "dropegg", pkFieldName = "seqId", pkFieldAssign = false)
public class DropEgg {
    private Long seqId;
    private String no;
    private String description;
    private String gameId;
    private int limitType;
    private int limitValue;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Long getSeqId() {
        return seqId;
    }
    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }
    public String getNo() {
        return no;
    }
    public void setNo(String no) {
        this.no = no;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getGameId() {
        return gameId;
    }
    public void setGameId(String gameId) {
        this.gameId = gameId;
    }
    public int getLimitType() {
        return limitType;
    }
    public void setLimitType(int limitType) {
        this.limitType = limitType;
    }
    public int getLimitValue() {
        return limitValue;
    }
    public void setLimitValue(int limitValue) {
        this.limitValue = limitValue;
    }
    public String getInputBy() {
        return inputBy;
    }
    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }
    public String getInputTime() {
        return inputTime;
    }
    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
    public String getEditBy() {
        return editBy;
    }
    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }
    public String getEditTime() {
        return editTime;
    }
    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

}

==> xlniuxdata-vipgame-1.1.5-20190424.035512-4-sources.jar: com/xunlei/niux/data/vipgame/vo/DropEgg.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

@Table(tableName = "dropegg", pkFieldName = "seqId", pkFieldAssign = false)
public class DropEgg {
    private Long seqId;
    private String no;
    private String description;
    private String gameId;
    private String gameNo;
    private int limitType;
    private int limitValue;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Long getSeqId() {
        return seqId;
    }
    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }
    public String getNo() {
        return no;
    }
    public void setNo(String no) {
        this.no = no;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getGameId() {
        return gameId;
    }
    public void setGameId(String gameId) {
        this.gameId = gameId;
    }
    public String getGameNo() {
        return gameNo;
    }
    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }
    public int getLimitType() {
        return limitType;
    }
    public void setLimitType(int limitType) {
        this.limitType = limitType;
    }
    public int getLimitValue() {
        return limitValue;
    }
    public void setLimitValue(int limitValue) {
        this.limitValue = limitValue;
    }
    public String getInputBy() {
        return inputBy;
    }
    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }
    public String getInputTime() {
        return inputTime;
    }
    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }
    public String getEditBy() {
        return editBy;
    }
    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }
    public String getEditTime() {
        return editTime;
    }
    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

}
